AbusHandler class abstract

Base interface for any state handler

Implementers

Constructors

AbusHandler()

Properties

handlerId → String
Get handler identifier for tracking
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canHandle(InteractionDefinition interaction) → bool
Check if this handler can handle the interaction
executeAPI(InteractionDefinition interaction) → Future<ABUSResult>?
Execute API call
getCurrentState(InteractionDefinition interaction) → Map<String, dynamic>?
Get current state for rollback capability
handleCommit(String interactionId, InteractionDefinition interaction) → Future<void>
Handle commit after successful API call
handleOptimistic(String interactionId, InteractionDefinition interaction) → Future<void>
Handle optimistic update for interaction
handleRollback(String interactionId, InteractionDefinition interaction) → Future<void>
Handle rollback for interaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited