CustomAbusHandler class abstract

Custom handler for projects not using BLoC or Provider

Implemented types
Implementers

Constructors

CustomAbusHandler()

Properties

handlerId → String
Get handler identifier for tracking
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canHandle(InteractionDefinition interaction) → bool
Check if this can handle the interaction
override
executeAPI(InteractionDefinition interaction) → Future<ABUSResult>?
Execute API call
override
getCurrentState(InteractionDefinition interaction) → Map<String, dynamic>?
Get current state for rollback capability
override
handleCommit(String interactionId, InteractionDefinition interaction) → Future<void>
Handle commit after successful API call
override
handleOptimistic(String interactionId, InteractionDefinition interaction) → Future<void>
Handle optimistic update for interaction
override
handleRollback(String interactionId, InteractionDefinition interaction) → Future<void>
Handle rollback for interaction
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited