FeedbackBus class

Main API for the feedback system

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

queue → List<FeedbackEvent>
Get current queue state
no setter

Static Methods

dismiss(String eventId) → Future<ABUSResult>
Dismiss feedback by ID
dismissAll() → Future<ABUSResult>
Dismiss all feedback
dismissByTags(Set<String> tags) → Future<ABUSResult>
Dismiss feedback by tags
initialize({AbusStorage? storage}) → Future<void>
Initialize the feedback system with optional storage persistence
showBanner({required String message, BannerType type = BannerType.info, List<BannerAction> actions = const [], Duration? duration, Set<String>? tags, int priority = 1, bool replace = false}) → Future<ABUSResult>
Show a banner
showSnackbar({required String message, SnackbarType type = SnackbarType.info, String? actionLabel, VoidCallback? onAction, Duration? duration, Set<String>? tags, int priority = 0, bool replace = false}) → Future<ABUSResult>
Show a snackbar
showToast({required String message, ToastType type = ToastType.info, Duration? duration, Set<String>? tags, int priority = 0, bool replace = false}) → Future<ABUSResult>
Show a toast
sync() → Future<void>
Manually sync feedback from storage (useful for cross-app updates)