ToastEvent class

Toast feedback event (platform agnostic)

Inheritance

Constructors

ToastEvent({required String id, required String message, ToastType type = ToastType.info, int priority = 0, Duration? duration = const Duration(seconds: 2), Set<String> tags = const {}, bool dismissible = false, Map<String, dynamic> metadata = const {}})
const

Properties

deduplicationKey → String
Create deduplication key for this event
no setterinherited
dismissible → bool
Whether this event can be dismissed by user
finalinherited
duration → Duration?
Duration to show the feedback
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for this feedback event
finalinherited
message → String
Message to display
finalinherited
metadata → Map<String, dynamic>
Metadata for additional properties
finalinherited
priority → int
Priority for ordering (higher = more important)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Set<String>
Tags for categorization and deduplication
finalinherited
type → ToastType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to JSON for serialization
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited